@@ -13,7 +13,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v0.20.0";
+our $VERSION = "v0.21.0";
 
 1;
 __END__
@@ -331,6 +331,15 @@ L<https://rxjs.dev/api/operators/filter>
         op_filter(sub {$_[0] % 2 == 0}),
     )->subscribe($observer);
 
+=item op_first
+
+L<https://rxjs.dev/api/operators/first>
+
+    # (pause 7 seconds) 6, complete
+    rx_interval(
+        op_first(sub { $_[0] > 5 }),
+    )->subscribe($observer);
+
 =item op_map
 
 L<https://rxjs.dev/api/operators/map>
@@ -346,7 +355,7 @@ L<https://rxjs.dev/api/operators/mapTo>
 
     # 123, 123, 123, ... (every 1 second)
     rx_interval(1)->pipe(
-        map_to(123),
+        op_map_to(123),
     )->subscribe($observer);
 
 =item op_merge_map
@@ -449,6 +458,20 @@ L<https://rxjs.dev/api/operators/takeUntil>
         op_take_until( rx_timer(5.5) ),
     )->subscribe($observer);
 
+=item op_take_while
+
+L<https://rxjs.dev/api/operators/takeWhile>
+
+    # 0, 1, 2, 3, 4, 5, complete
+    rx_interval(1)->pipe(
+        op_take_while(sub { $_[0] <= 5 }),
+    )->subscribe($observer);
+
+    # 0, 1, 2, 3, 4, 5, 6, complete
+    rx_interval(1)->pipe(
+        op_take_while(sub { $_[0] <= 5 }, 1),
+    )->subscribe($observer);
+
 =item op_tap
 
 L<https://rxjs.dev/api/operators/tap>
@@ -559,6 +582,18 @@ L<ReactiveX API|http://reactivex.io/documentation/operators.html> at a few point
 L<Rx* libraries|http://reactivex.io/languages.html>), RxPerl chose to behave like rxjs rather than
 ReactiveX to cater for web developers already familiar with rxjs.
 
+=head1 LEARNING MATERIAL
+
+=over
+
+=item * L<Ultimate RxJS courses|https://ultimatecourses.com/courses/rxjs>
+
+=item * L<egghead RxJS courses|https://egghead.io/browse/libraries/rxjs>
+
+=item * L<Rx Marbles|https://rxmarbles.com/>
+
+=back
+
 =head1 TODO
 
 =over
@@ -573,9 +608,7 @@ ReactiveX to cater for web developers already familiar with rxjs.
 
 =over
 
-=item * L<Rx Marbles|https://rxmarbles.com/>
-
-=item * L<Ryu module's SEE ALSO section|https://metacpan.org/pod/Ryu#SEE-ALSO>
+=item * L<Ryu|https://metacpan.org/pod/Ryu>
 
 =back
 
