@@ -12,8 +12,8 @@ use Scalar::Util 'reftype', 'refaddr';
 
 use Exporter 'import';
 our @EXPORT_OK = qw/
-    op_delay op_distinct_until_changed op_filter op_map op_map_to op_merge_map op_multicast
-    op_pairwise op_ref_count op_scan op_share op_start_with op_switch_map op_take op_take_until op_tap
+    op_delay op_distinct_until_changed op_filter op_first op_map op_map_to op_merge_map op_multicast
+    op_pairwise op_ref_count op_scan op_share op_start_with op_switch_map op_take op_take_until op_take_while op_tap
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
@@ -94,12 +94,12 @@ sub op_distinct_until_changed {
             my $own_subscriber = {
                 %$subscriber,
                 next => sub {
-                    my ($value) = @_;
+                    my @value = @_;
 
-                    if (! $have_prev_value or ! _eqq($prev_value, $value)) {
-                        $subscriber->{next}->($value) if defined $subscriber->{next};
+                    if (! $have_prev_value or ! _eqq($prev_value, $value[0])) {
+                        $subscriber->{next}->(@value) if defined $subscriber->{next};
                         $have_prev_value = 1;
-                        $prev_value = $value;
+                        $prev_value = $value[0];
                     }
                 },
             };
@@ -137,6 +137,19 @@ sub op_filter {
     };
 }
 
+sub op_first {
+    my ($condition) = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        my @pipes = (op_take(1));
+        unshift @pipes, op_filter($condition) if defined $condition;
+
+        return $source->pipe(@pipes);
+    };
+}
+
 sub op_map {
     my ($mapping_sub) = @_;
 
@@ -499,6 +512,37 @@ sub op_take_until {
     };
 }
 
+sub op_take_while {
+    my ($cond, $include) = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my $own_subscriber = {
+                %$subscriber,
+                next => sub {
+                    my ($value) = @_;
+
+                    if (! $cond->($value)) {
+                        $subscriber->{next}->($value) if $include and defined $subscriber->{next};
+                        $subscriber->{complete}->() if defined $subscriber->{complete};
+                        return;
+                    }
+
+                    $subscriber->{next}->(@_) if defined $subscriber->{next};
+                },
+            };
+
+            $source->subscribe($own_subscriber);
+
+            return;
+        });
+    };
+}
+
 sub op_tap {
     my @args = @_;
 
